@@ -125,6 +125,19 @@ def make_password(master_password, domain_key, lowercase=True, uppercase=True,
     return bytes2string(hash, alphabet)[:length]
 
 
+def get_password(domain_key=None, lowercase=True, uppercase=True,
+                 digits=True, length=DEFAULT_LENGTH, alphabet=None):
+    """Prompt for master password and domain key. Return a password"""
+    # password and domain prefix (if None) are read interactively from stdin to
+    # avoid password data to be stored in the shell command history
+    master_password = getpass("master password: ")
+    if domain_key is None:
+        domain_key = raw_input("domain key [e.g. 'login@host']: ")
+    return make_password(master_password, domain_key,
+                         uppercase=uppercase, digits=digits,
+                         length=length, alphabet=alphabet)
+
+
 def parse_args(args):
     usage = "vkr -l 10 -a abcdefghijklmnopqrstuvwyz0123456789"
     parser = optparse.OptionParser(usage=usage)
@@ -148,13 +161,9 @@ def parse_args(args):
 def main():
     options, _ = parse_args(sys.argv)
 
-    # password and domain prefix are read interactively from stdin to avoid
-    # password data to be stored in the shell command history
-    master_password = getpass("master password: ")
-    domain_key = raw_input("domain key [e.g. 'login@host']: ")
-    print "your password is:", make_password(master_password, domain_key,
-                                             length=options.length,
-                                             alphabet=options.alphabet)
+    passwd = get_password(length=options.length,
+                          alphabet=options.alphabet)
+    print "your password is:", passwd
     print "please clean your console (ctrl-L) after usage"
 
 
